==> mpf-0.57.0.dev29.tar.gz: mpf-0.57.0.dev29/README.md <==
Mission Pinball Framework (MPF)
===============================

<img align="center" height="146" src="https://missionpinball.org/images/mpf-logo-full.png"/>

<em>...Let's build a pinball machine!</em>

What is Mission Pinball Framework?
----------------------------------

Mission Pinball Framework (MPF) is open source, cross-platform software for powering real pinball
machines. MPF is a community-developed project released under the MIT license. It's supported by volunteers in their spare time.

[![Coverage Status](https://coveralls.io/repos/missionpinball/mpf/badge.svg?branch=dev&service=github)](https://coveralls.io/github/missionpinball/mpf?branch=dev)
[![Test Status](https://github.com/missionpinball/mpf/actions/workflows/run_tests.yml/badge.svg)](https://github.com/missionpinball/mpf/actions/workflows/run_tests.yml)
[![CII Best Practices](https://bestpractices.coreinfrastructure.org/projects/1687/badge)](https://bestpractices.coreinfrastructure.org/projects/1687)

Visit the MPF project homepage at https://missionpinball.org. Additional related projects exist as part of the MPF ecosystem, including the "MPF Monitor" which is a graphical application that lets you simulate pinball hardware, and "MPF-MC" which is a media controller which provides graphics and sounds for pinball machines.

Documentation
-------------

* User Docs (installation, tutorials, & reference): https://missionpinball.org

Support
-------

MPF is an open source community project which has no official support. Some MPF users participate in the MPF-Users Google group or GitHub Discussion. Links [here](https://missionpinball.org/community/).

Individual pinball hardware companies may provide additional support for users of their hardware, often via their own Slack, Discord, or other chat groups. If you get stuck, you can ask for help in the MPF-users group, or you reach out to your hardware provider.

Maintenance, Pull Requests, & Bug Fixes
---------------------------------------

As a community project, we welcome pull requests and bug fixes. However, we do not have the resources to provide support for MPF. If you are interested in becoming a maintainer, please contact us at brian@missionpinball.org.

Bugs or other issues related to MPF itself can be posted to the [MPF Discussions page on GitHub](https://missionpinball.org/community/).

Contributing
------------

Individual pinball hardware makers are responsible for their own platform interface maintenance and contributions.

MPF is a passion project created and maintained by volunteers. If you're a Python coder, documentation writer, or pinball maker, feel free to make a change and submit a pull request. For more information about contributing see the [Contributing Code](https://missionpinball.org/about/contributing_to_mpf/)
and [Contributing Documentation](https://missionpinball.org/about/help_docs/) pages.

License
-------

MPF and related projects are released under the MIT License. Refer to the LICENSE file for details. Docs are released under Creative Commons CC BY 4.0.

==> mpf-0.80.0.dev8.tar.gz: mpf-0.80.0.dev8/README.md <==
Mission Pinball Framework (MPF)
===============================

<img align="center" height="146" src="https://missionpinball.org/latest/images/mpf-logo-full.png"/>

<em>...Let's build a pinball machine!</em>

What is Mission Pinball Framework?
----------------------------------

Mission Pinball Framework (MPF) is open source, cross-platform software for powering real pinball
machines. MPF is a community-developed project released under the MIT license. It's supported by volunteers in their spare time.

[![Coverage Status](https://coveralls.io/repos/missionpinball/mpf/badge.svg?branch=dev&service=github)](https://coveralls.io/github/missionpinball/mpf?branch=dev)
[![Test Status](https://github.com/missionpinball/mpf/actions/workflows/run_tests.yml/badge.svg)](https://github.com/missionpinball/mpf/actions/workflows/run_tests.yml)
[![CII Best Practices](https://bestpractices.coreinfrastructure.org/projects/1687/badge)](https://bestpractices.coreinfrastructure.org/projects/1687)

Visit the MPF project homepage at https://missionpinball.org. Additional related projects exist as part of the MPF ecosystem, including the "MPF Monitor" which is a graphical application that lets you simulate pinball hardware, and "MPF-MC" which is a media controller which provides graphics and sounds for pinball machines.

Documentation
-------------

* User Docs (installation, tutorials, & reference): https://missionpinball.org

Support
-------

MPF is an open source community project which has no official support. Some MPF users participate in the MPF-Users Google group or GitHub Discussion. Links [here](https://missionpinball.org/latest/community/).

Individual pinball hardware companies may provide additional support for users of their hardware, often via their own Slack, Discord, or other chat groups. If you get stuck, you can ask for help in the MPF-users group, or you reach out to your hardware provider.

Maintenance, Pull Requests, & Bug Fixes
---------------------------------------

As a community project, we welcome pull requests and bug fixes. However, we do not have the resources to provide support for MPF. If you are interested in becoming a maintainer, please contact us at brian@missionpinball.org.

Bugs or other issues related to MPF itself can be posted to the [MPF Discussions page on GitHub](https://missionpinball.org/latest/community/).

Contributing
------------

Individual pinball hardware makers are responsible for their own platform interface maintenance and contributions.

MPF is a passion project created and maintained by volunteers. If you're a Python coder, documentation writer, or pinball maker, feel free to make a change and submit a pull request. For more information about contributing see the [Contributing Code](https://missionpinball.org/latest/about/contributing_to_mpf/)
and [Contributing Documentation](https://missionpinball.org/latest/about/help_docs/) pages.

License
-------

MPF and related projects are released under the MIT License. Refer to the LICENSE file for details. Docs are released under Creative Commons CC BY 4.0.
